==> auto-ui-2.1.28.tgz: package/es/button/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { Link } from 'react-router-dom';
import Spin from '../spin/index';
import './style.scss';
var Button = function (props) {
    var type = props.type, disabled = props.disabled, shrink = props.shrink, capsule = props.capsule, mini = props.mini, hollow = props.hollow, shadow = props.shadow, loading = props.loading, className = props.className, children = props.children, onClick = props.onClick, to = props.to, href = props.href, otherProps = __rest(props, ["type", "disabled", "shrink", "capsule", "mini", "hollow", "shadow", "loading", "className", "children", "onClick", "to", "href"]);
    var composeClassName = cn('x-button', {
        'x-button--disabled': disabled,
        'x-button--loading': loading,
        'x-button--mini': mini,
        'x-button--capsule': capsule,
        'x-button--hollow': hollow,
        'x-button--shrink': shrink !== void 0 ? shrink : !!mini,
        'x-button--shadow': (type === 'primary' || type === 'danger') && !hollow && shadow,
    }, "x-button--" + type, className);
    var content = function () { return (React.createElement(React.Fragment, null,
        !!loading && React.createElement(Spin, { className: "x-button__loading" }),
        children)); };
    if (onClick) {
        var clickHandle = function (evt) {
            if (disabled || loading || !onClick) {
                return;
            }
            onClick(evt);
        };
        return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: clickHandle }), content()));
    }
    if (to) {
        return (React.createElement(Link, __assign({}, otherProps, { className: composeClassName, to: to }), content()));
    }
    if (href) {
        return (React.createElement("a", __assign({}, otherProps, { className: composeClassName, href: href }), content()));
    }
    return (React.createElement("button", __assign({}, otherProps, { className: composeClassName }), content()));
};
Button.defaultProps = {
    type: 'primary',
    capsule: true,
};
export default Button;

==> auto-ui-2.1.54.tgz: package/es/button/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { Link } from 'react-router-dom';
import Spin from '../spin/index';
import './style.scss';
var Button = function (props) {
    var type = props.type, disabled = props.disabled, shrink = props.shrink, capsule = props.capsule, mini = props.mini, hollow = props.hollow, shadow = props.shadow, loading = props.loading, className = props.className, children = props.children, onClick = props.onClick, to = props.to, href = props.href, otherProps = __rest(props, ["type", "disabled", "shrink", "capsule", "mini", "hollow", "shadow", "loading", "className", "children", "onClick", "to", "href"]);
    var composeClassName = cn('x-button', {
        'x-button--disabled': disabled,
        'x-button--loading': loading,
        'x-button--mini': mini,
        'x-button--capsule': capsule,
        'x-button--hollow': hollow,
        'x-button--shrink': shrink !== void 0 ? shrink : !!mini,
        'x-button--shadow': (type === 'primary' || type === 'danger') && !hollow && shadow,
    }, "x-button--" + type, className);
    var content = function () { return (React.createElement(React.Fragment, null,
        !!loading && React.createElement(Spin, { className: "x-button__loading" }),
        children)); };
    if (onClick) {
        var clickHandle = function (evt) {
            if (disabled || loading || !onClick) {
                return;
            }
            onClick(evt);
        };
        return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: clickHandle }), content()));
    }
    if (to) {
        return (React.createElement(Link, __assign({}, otherProps, { className: composeClassName, to: to }), content()));
    }
    if (href) {
        return (React.createElement("a", __assign({}, otherProps, { className: composeClassName, href: href }), content()));
    }
    return (React.createElement("button", __assign({}, otherProps, { className: composeClassName }), content()));
};
Button.defaultProps = {
    type: 'primary',
    capsule: true,
};
export default Button;
